==> haskell-bzlib-0.5.2.0-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bzlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bzlib
version:              0.5.2.0
visibility:           public
id:                   bzlib-0.5.2.0-CEbyWLXj5iHEd6l3mVeou4
key:                  bzlib-0.5.2.0-CEbyWLXj5iHEd6l3mVeou4
license:              BSD-3-Clause
copyright:            (c) 2006-2015 Duncan Coutts
maintainer:           Duncan Coutts <duncan@community.haskell.org>
author:               Duncan Coutts <duncan@community.haskell.org>
synopsis:             Compression and decompression in the bzip2 format
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the bz2 C library so it has high
    performance.

    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full bzip2 feature set.

category:             Codec
abi:                  6d54653750e2c2a890d62ee238c0e21f
exposed:              True
exposed-modules:
    Codec.Compression.BZip Codec.Compression.BZip.Internal

hidden-modules:       Codec.Compression.BZip.Stream
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bzlib-0.5.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bzlib-0.5.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bzlib-0.5.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bzlib
hs-libraries:         HSbzlib-0.5.2.0-CEbyWLXj5iHEd6l3mVeou4
extra-libraries:      bz2
includes:             bzlib.h
depends:              base-4.17.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-bzlib/html/bzlib.haddock
haddock-html:         /usr/share/doc/haskell-bzlib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bzlib-0.5.2.0-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bzlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bzlib
version:              0.5.2.0
visibility:           public
id:                   bzlib-0.5.2.0-HK1PBlmSk9AGv6VME8VZmM
key:                  bzlib-0.5.2.0-HK1PBlmSk9AGv6VME8VZmM
license:              BSD-3-Clause
copyright:            (c) 2006-2015 Duncan Coutts
maintainer:           Duncan Coutts <duncan@community.haskell.org>
author:               Duncan Coutts <duncan@community.haskell.org>
synopsis:             Compression and decompression in the bzip2 format
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the bz2 C library so it has high
    performance.

    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full bzip2 feature set.

category:             Codec
abi:                  dfd2d8ea0971860b9b1a0767aa6b3562
exposed:              True
exposed-modules:
    Codec.Compression.BZip Codec.Compression.BZip.Internal

hidden-modules:       Codec.Compression.BZip.Stream
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bzlib-0.5.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bzlib-0.5.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bzlib-0.5.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bzlib
hs-libraries:         HSbzlib-0.5.2.0-HK1PBlmSk9AGv6VME8VZmM
extra-libraries:      bz2
includes:             bzlib.h
depends:              base-4.17.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-bzlib/html/bzlib.haddock
haddock-html:         /usr/share/doc/haskell-bzlib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
